@@ -23,70 +23,6 @@
 #include "redmond_gtk2_drawing.h"
 #include "redmond_gtk2_misc.h"
  
-void
-do_redmond_draw_pattern_fill (cairo_t * cr,
-                                  CairoPattern *pattern,
-                                  gint x,
-                                  gint y, 
-                                  gint width, 
-                                  gint height)
-{
-	cairo_matrix_t original_matrix, current_matrix;
-
-	cairo_pattern_get_matrix(pattern->handle, &original_matrix);
-	current_matrix = original_matrix;
-
-	if (pattern->scale != REDMOND_DIRECTION_NONE)
-	{
-		gdouble scale_x = 1.0;
-		gdouble scale_y = 1.0;
-
-		if ((pattern->scale == REDMOND_DIRECTION_VERTICAL) || (pattern->scale == REDMOND_DIRECTION_BOTH))
-		{
-			scale_x = 1.0/width;
-		}
-
-		if ((pattern->scale == REDMOND_DIRECTION_HORIZONTAL) || (pattern->scale == REDMOND_DIRECTION_BOTH))
-		{
-			scale_y = 1.0/height;
-		}
-
-		cairo_matrix_scale(&current_matrix, scale_x, scale_y);
-	}
-
-	if (pattern->translate != REDMOND_DIRECTION_NONE)
-	{
-		gdouble translate_x = 0;
-		gdouble translate_y = 0;
-
-		if ((pattern->translate == REDMOND_DIRECTION_VERTICAL) || (pattern->translate == REDMOND_DIRECTION_BOTH))
-		{
-			translate_x = -x;
-		}
-
-		if ((pattern->translate == REDMOND_DIRECTION_HORIZONTAL) || (pattern->translate == REDMOND_DIRECTION_BOTH))
-		{
-			translate_y = -y;
-		}
-
-		cairo_matrix_translate(&current_matrix, translate_x, translate_y);
-	}
-
-	cairo_pattern_set_matrix(pattern->handle, &current_matrix);
-
-	cairo_save(cr);
-
-	cairo_set_source(cr, pattern->handle);
-
-	cairo_rectangle(cr, x, y, width, height);
-
-	cairo_fill (cr);
-
-	cairo_restore(cr);
-
-	cairo_pattern_set_matrix(pattern->handle, &original_matrix);
-}
- 
 void
 do_redmond_draw_masked_fill (cairo_t * cr,
                                   CairoPattern *mask,
@@ -102,8 +38,11 @@ do_redmond_draw_masked_fill (cairo_t * cr,
 	cairo_fill(cr);
 
 	ge_cairo_set_color(cr, foreground);
+	cairo_save (cr);
 	cairo_rectangle (cr, x, y, width, height);
+	cairo_clip (cr);
 	cairo_mask (cr, mask->handle);
+	cairo_restore (cr);
 }
   
 /***********************************************
@@ -370,14 +309,14 @@ do_redmond_draw_simple_circle (cairo_t *canvas,
       cairo_save(canvas);
 
       cairo_move_to(canvas, center_x + (radius + 2), center_y + (radius + 2));
-      cairo_line_to(canvas, center_x + (radius + 2)*sin(M_PI/4.0), center_y - (radius + 2)*cos(M_PI/4.0));
-      cairo_line_to(canvas, center_x - (radius + 2)*sin(M_PI/4.0), center_y + (radius + 2)*cos(M_PI/4.0));
+      cairo_line_to(canvas, center_x + (radius + 2)*sin(G_PI/4.0), center_y - (radius + 2)*cos(G_PI/4.0));
+      cairo_line_to(canvas, center_x - (radius + 2)*sin(G_PI/4.0), center_y + (radius + 2)*cos(G_PI/4.0));
       cairo_line_to(canvas, center_x + (radius + 2), center_y + (radius + 2));
 
       cairo_clip (canvas);
 
       ge_cairo_set_color(canvas, br);
-      cairo_arc(canvas, center_x, center_y, radius, 0,  2*M_PI);
+      cairo_arc(canvas, center_x, center_y, radius, 0,  2*G_PI);
       cairo_fill(canvas);
 
       cairo_restore(canvas);
@@ -385,14 +324,14 @@ do_redmond_draw_simple_circle (cairo_t *canvas,
       cairo_save(canvas);
 
       cairo_move_to(canvas, center_x - (radius + 2), center_y - (radius + 2));
-      cairo_line_to(canvas, center_x + (radius + 2)*sin(M_PI/4.0), center_y - (radius + 2)*cos(M_PI/4.0));
-      cairo_line_to(canvas, center_x - (radius + 2)*sin(M_PI/4.0), center_y + (radius + 2)*cos(M_PI/4.0));
+      cairo_line_to(canvas, center_x + (radius + 2)*sin(G_PI/4.0), center_y - (radius + 2)*cos(G_PI/4.0));
+      cairo_line_to(canvas, center_x - (radius + 2)*sin(G_PI/4.0), center_y + (radius + 2)*cos(G_PI/4.0));
       cairo_line_to(canvas, center_x - (radius + 2), center_y - (radius + 2));
 
       cairo_clip (canvas);
 
       ge_cairo_set_color(canvas, tl); 
-      cairo_arc(canvas, center_x, center_y, radius, 0, 2*M_PI);
+      cairo_arc(canvas, center_x, center_y, radius, 0, 2*G_PI);
       cairo_fill(canvas);
 
       cairo_restore(canvas);
